@@ -53,6 +53,24 @@ impl<T, const N: usize> AsRef<[T]> for RedactedArray<T, N> {
     }
 }
 
+impl<T, const N: usize> AsMut<[T]> for RedactedArray<T, N> {
+    fn as_mut(&mut self) -> &mut [T] {
+        &mut self.items
+    }
+}
+
+impl<T, const N: usize> AsRef<[T; N]> for RedactedArray<T, N> {
+    fn as_ref(&self) -> &[T; N] {
+        &self.items
+    }
+}
+
+impl<T, const N: usize> AsMut<[T; N]> for RedactedArray<T, N> {
+    fn as_mut(&mut self) -> &mut [T; N] {
+        &mut self.items
+    }
+}
+
 impl<T, const N: usize> RedactedArray<T, N> {
     /// Create a new `RedactedArray` from the provided array
     pub fn new(items: [T; N]) -> Self {
