@@ -59,6 +59,24 @@ impl<const N: usize> AsRef<[u8]> for RedactedBytes<N> {
     }
 }
 
+impl<const N: usize> AsMut<[u8]> for RedactedBytes<N> {
+    fn as_mut(&mut self) -> &mut [u8] {
+        &mut self.items
+    }
+}
+
+impl<const N: usize> AsRef<[u8; N]> for RedactedBytes<N> {
+    fn as_ref(&self) -> &[u8; N] {
+        &self.items
+    }
+}
+
+impl<const N: usize> AsMut<[u8; N]> for RedactedBytes<N> {
+    fn as_mut(&mut self) -> &mut [u8; N] {
+        &mut self.items
+    }
+}
+
 impl<const N: usize> RedactedBytes<N> {
     /// Create a new `RedactedBytes` from the provided array
     pub fn new(items: [u8; N]) -> Self {
